@@ -33,8 +33,7 @@ setClass("MultivariateDistribution",
             prototype = prototype(r = function(n){ matrix(rep(c(0,0), n), ncol=2) }, 
                                   d = NULL, p = NULL, q = NULL, param = NULL,
                                   img = new("EuclideanSpace", dimension = 2),
-                                  support = matrix(c(0,0), ncol = 2), .withSim = FALSE, 
-                                  .withArith = FALSE ),
+                                  support = matrix(c(0,0), ncol = 2)),
             contains = "Distribution")
 
 # discrete mulitvariate distribution
@@ -42,8 +41,7 @@ setClass("DiscreteMVDistribution", representation(support = "matrix"),
             prototype(r = function(n){ matrix(rep(c(0,0), n), ncol=2) }, 
                       d = NULL, p = NULL, q = NULL, param = NULL,
                       img = new("EuclideanSpace", dimension = 2),
-                      support = matrix(c(0,0), ncol = 2), .withSim = FALSE, 
-                      .withArith = FALSE ),
+                      support = matrix(c(0,0), ncol = 2)),
             contains = "MultivariateDistribution")
 
 # condition
@@ -62,8 +60,7 @@ setClass("UnivariateCondDistribution",
             representation(cond = "Condition"), 
             prototype(r = function(n, cond){ rnorm(n, mean = 0, sd = 1) },
                       d = NULL, p = NULL, q = NULL, img = new("Reals"), 
-                      param = NULL, cond = new("Condition"), .withSim = FALSE, 
-                      .withArith = FALSE),
+                      param = NULL, cond = new("Condition")),
             contains = "Distribution")
 
 # absolutely continuous conditional distribution
@@ -71,8 +68,7 @@ setClass("AbscontCondDistribution",
             representation(cond = "Condition"), 
             prototype(r = function(n, cond){ rnorm(n, mean = 0, sd = 1) },
                       d = NULL, p = NULL, q = NULL, img = new("Reals"), 
-                      param = NULL, cond = new("Condition"), .withSim = FALSE, 
-                      .withArith = FALSE),
+                      param = NULL, cond = new("Condition")),
             contains = "UnivariateCondDistribution")
 
 # discrete conditional distribution
@@ -82,8 +78,7 @@ setClass("DiscreteCondDistribution",
             prototype(r = function(n, cond){ rep(0, n) },
                       d = NULL, p = NULL, q = NULL, img = new("Reals"), 
                       param = NULL, support = function(cond){0},
-                      cond = new("Condition"), .withSim = FALSE, 
-                      .withArith = FALSE),
+                      cond = new("Condition")),
             contains = "UnivariateCondDistribution")
 
 # parameter of Gumbel distribution
@@ -105,13 +100,38 @@ setClass("GumbelParameter", representation(loc = "numeric",
 # Gumbel distribution
 setClass("Gumbel", 
             prototype = prototype(r = function(n){ rgumbel(n, loc = 0, scale = 1) },
-                                  d = function(x, ...){ dgumbel(x, loc = 0, scale = 1, ...) },
-                                  p = function(q, ...){ pgumbel(q, loc = 0, scale = 1, ...) },
-                                  q = function(p, ...){ qgumbel(p, loc = 0, scale = 1, ...) },
+                                  d = function(x, log){dgumbel(x, loc = 0, scale = 1, log = FALSE)},
+                                  p = function(q, lower.tail = TRUE, log.p = FALSE){ 
+                                         p0 <- pgumbel(q, loc = 0, scale = 1, lower.tail = lower.tail)
+                                         if(log.p) return(log(p0)) else return(p0) 
+                                  },
+                                  q = function(p, loc = 0, scale = 1, lower.tail = TRUE, log.p = FALSE){
+                                      ## P.R.: changed to vectorized form 
+                                      p1 <- if(log.p) exp(p) else p
+                                                                                      
+                                      in01 <- (p1>1 | p1<0)
+                                      i01 <- .isEqual01(p1) 
+                                      i0 <- (i01 & p1<1)   
+                                      i1 <- (i01 & p1>0)
+                                      ii01 <- .isEqual01(p1) | in01
+                                                    
+                                      p0 <- p
+                                      p0[ii01] <- if(log.p) log(0.5) else 0.5
+                                                    
+                                      q1 <- qgumbel(p0, loc = 0, scale = 1, 
+                                                    lower.tail = lower.tail) 
+                                      q1[i0] <- if(lower.tail) -Inf else Inf
+                                      q1[i1] <- if(!lower.tail) -Inf else Inf
+                                      q1[in01] <- NaN
+                                      
+                                      return(q1)  
+                                      },
                                   img = new("Reals"),
                                   param = new("GumbelParameter"),
                                   .withArith = FALSE,
-                                  .withSim = FALSE),
+                                  .withSim = FALSE,
+                                  .logExact = FALSE,
+                                  .lowerExact = TRUE),
             contains = "AbscontDistribution")
 
 # Parameter of a linear regression model (with intercept and scale)
@@ -135,3 +155,58 @@ setClass("LMParameter",
                     stop("inifinite or missing value in 'scale'")
                 return(TRUE)
             })
+
+
+###### Pareto distribution by Nataliya Horbenko, ITWM, 18-03-09
+## Class: ParetoParameter
+setClass("ParetoParameter", 
+          representation = representation(shape = "numeric",
+                                          Min = "numeric"
+                                          ), 
+          prototype = prototype(shape = 1, Min = 1, name = 
+                      gettext("Parameter of a Pareto distribution")
+                      ), 
+          contains = "Parameter"
+          )
+
+## Class: Pareto distribution
+setClass("Pareto",  
+          prototype = prototype(
+                      r = function(n){ rpareto1(n, shape = 1, min = 1) },
+                      d = function(x, log = FALSE){ 
+                              dpareto1(x, shape = 1, min = 1, log = log) 
+                                          },
+                      p = function(q, lower.tail = TRUE, log.p = FALSE ){ 
+                              ppareto1(q, shape = 1, min = 1, 
+                                     lower.tail = lower.tail, log.p = log.p) 
+                                          },
+                      q = function(p, lower.tail = TRUE, log.p = FALSE ){ 
+                        ## P.R.: changed to vectorized form 
+                               p1 <- if(log.p) exp(p) else p
+                                                                               
+                               in01 <- (p1>1 | p1<0)
+                               i01 <- .isEqual01(p1) 
+                               i0 <- (i01 & p1<1)   
+                               i1 <- (i01 & p1>0)
+                               ii01 <- .isEqual01(p1) | in01
+                                             
+                               p0 <- p
+                               p0[ii01] <- if(log.p) log(0.5) else 0.5
+                                             
+                               q1 <- qpareto1(p0, shape = 1,  min =  1, 
+                                           lower.tail = lower.tail, log.p = log.p) 
+                               q1[i0] <- if(lower.tail) -Inf else Inf
+                               q1[i1] <- if(!lower.tail) -Inf else Inf
+                               q1[in01] <- NaN
+                               
+                               return(q1)  
+                            },
+                      param = new("ParetoParameter"),
+                      img = new("Reals"),
+                      .withArith = FALSE,
+                      .withSim = FALSE,
+                      .logExact = TRUE,
+                      .lowerExact = TRUE),
+          contains = "AbscontDistribution"
+          )
+
